The basefun package offers a small collection of objects for
handling basis functions and corresponding methods. The package was written to support the mlt
package and will be of limited use outside this package.
The user interface is not yet stable, so please be careful using
basefun in your package.