| cyclic_basis | R Documentation |
The cyclic basis function for modelling seasonal effects
cyclic_basis(var, order = 3, frequency)
var |
a |
order |
the order of the basis function |
frequency |
frequency |
cyclic_basis returns a set of sin and cosine functions for
modelling seasonal effects, see \bibcitetbasefun::Held_Paul_2012, Section 2.2.
For any choice of coefficients, the function returns the same value
when evaluated at multiples of frequency.
*
### set-up basis
cb <- cyclic_basis(numeric_var("x"), order = 3, frequency = 2 * pi)
### generate data + coefficients
x <- data.frame(x = c(0, pi, 2 * pi))
### f(0) = f(2 * pi)
cb(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.