basefun-package: General Information on the 'basefun' Package

basefun-packageR Documentation

General Information on the basefun Package

Description

The basefun package offers a small collection of objects for handling basis functions and corresponding methods.

Details

The package was written to support the mlt package \bibcitepbasefun::Hothorn:2018 and will be of limited use outside this package.

References

\bibshow

*


basefun documentation built on March 7, 2026, 1:07 a.m.