| basefun-package | R Documentation |
The basefun package offers a small collection of objects for handling basis functions and corresponding methods.
The package was written to support the mlt package \bibcitepbasefun::Hothorn:2018 and will be of limited use outside this package.
*
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.