Learn R Programming

basefun (version 1.2-6)

basefun-package: General Information on the basefun Package

Description

The basefun package offers a small collection of objects for handling basis functions and corresponding methods.

Arguments

Details

The package was written to support the mlt package basefun::Hothorn:2018 and will be of limited use outside this package.

References

*