powered by
The basefun package offers a small collection of objects for handling basis functions and corresponding methods.
The package was written to support the mlt package basefun::Hothorn:2018 and will be of limited use outside this package.
*